Struct MdioDriver
Source pub struct MdioDriver<'a> { }
Thin wrapper that exposes Clause 22 MDIO read/write over the EMAC MAC’s
built-in MDIO controller.
Implements MdioBus, so PHY drivers generic over MdioBus can run
directly on top of this MAC without any adapter.
Reads one PHY register (Clause 22).
Writes one PHY register (Clause 22).
SourceAvailable on crate feature unstable only.
Read a 16-bit PHY register.
Write a 16-bit PHY register.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.